@@ -7,6 +7,10 @@
  */
 
 #include "timer.h"
+#include "alarmplayer.h"
+
+#include <QFile>
+#include <QStandardPaths>
 
 Timer::Timer(int length, const QString &label, const QString &commandTimeout, bool running, QObject *parent)
     : QObject{parent}
@@ -40,6 +44,11 @@ Timer::~Timer()
         // stop wakeup if timer is being deleted
         setRunning(false);
     }
+
+    // ensure timer doesn't continue ringing after deletion
+    if (m_ringing) {
+        AlarmPlayer::instance().stop();
+    }
 }
 
 void Timer::init()
@@ -254,6 +263,9 @@ void Timer::ring()
 
     Utilities::pauseMprisSources();
 
+    AlarmPlayer::instance().setSource(findRingSoundLocation());
+    AlarmPlayer::instance().play();
+
     m_ringing = true;
     Q_EMIT ringingChanged();
 }
@@ -263,6 +275,8 @@ void Timer::dismiss()
     qDebug() << "Timer dismissed.";
     m_notification->close();
 
+    AlarmPlayer::instance().stop();
+
     Utilities::resumeMprisSources();
 
     m_ringing = false;
@@ -275,3 +289,18 @@ void Timer::reschedule()
         m_cookie = Utilities::instance().scheduleWakeup(m_startTime + m_length);
     }
 }
+
+QUrl Timer::findRingSoundLocation()
+{
+    const auto locations = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+    const QString path = QStringLiteral("/sounds/freedesktop/stereo/alarm-clock-elapsed.oga");
+    QString alarmSoundPath;
+
+    for (const auto &directory : locations) {
+        if (QFile(directory + path).exists()) {
+            return QUrl(directory + path);
+        }
+    }
+
+    return QUrl();
+}
\ No newline at end of file
